..
    Copyright (C) 2019 CIS UCT Prague.

    CIS theses repository is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

============================================================
 Invenio Explicit ACLs
============================================================

.. image:: https://readthedocs.org/projects/invenio-explicit-acls/badge/?version=latest
        :target: https://invenio-explicit-acls.readthedocs.io/

.. image:: https://img.shields.io/github/license/oarepo/invenio-explicit-acls.svg
        :target: https://github.com/oarepo/invenio-explicit-acls/blob/master/LICENSE

.. image:: https://img.shields.io/travis/oarepo/invenio-explicit-acls.svg
        :target: https://travis-ci.org/oarepo/invenio-explicit-acls

.. image:: https://img.shields.io/coveralls/oarepo/invenio-explicit-acls.svg
        :target: https://coveralls.io/r/oarepo/invenio-explicit-acls

.. image:: https://img.shields.io/pypi/v/invenio-explicit-acls.svg
        :target: https://pypi.org/pypi/invenio-explicit-acls

A package that adds support for elasticsearch-executed declarative ACLs.
For rationale see slide 27 of
https://indico.cern.ch/event/773969/contributions/3351844/attachments/1814264/2967405/Access_management-Karolina.pdf

Further documentation is available on
https://invenio-explicit-acls.readthedocs.io/

==========================================================
